##########################################################
##                                                      ##
##    Teilskript 1: Herunterladen und Aufbereitung von  ##
##                  Beispieldaten                       ##
##                                                      ##
##########################################################

#############################################################
# falls session unterbrochen wurde: risktool-settings.r erneut laden.
#source("./code/risktool-settings.r")

#############################################################
# Herunterladen und Entpacken von Beispieldaten
# Hinweis: das automatische Enpacken mittels unzip() funktioniert unter Umständen
#          nicht. In diesem Fall bitte von Hand entpacken.
#          Getestet:
#          R 3.2.4/Linux funktioniert
#          R 3.2.3/Windows 10 funktioniert
#          R 3.2.2/Wintows 7 funktioniert nicht

# Bioclim-Datensatz fuer derzeitige Klimabedingungen (baseline) in 5-Bogenminuten-Aufloesung
# ACHTUNG: Die folgenden Daten duerfen nur fuer nicht-kommerzielle Zwecke verwendet
# und nicht ohne Einverstaendnis der Anbieter weiterverbreitet werden.
# Details siehe http://www.worldclim.com/current
download.file(url="http://biogeo.ucdavis.edu/data/climate/worldclim/1_4/grid/cur/bio_5m_esri.zip",
              destfile=paste0(path.envir.baseline, "bio_5m_esri.zip"),
              method="internal", mode="wb")
unzip(zipfile=paste0(path.envir.baseline, "bio_5m_esri.zip"), exdir=path.envir.baseline)

# Bioclim-Datensatz fuer zukuenftige Klimabedingungen in 5-Bogenminuten-Aufloesung
# Hier: Klimamodell HadGEM2-AO, RCP 4.5, Zeitabschnitt 2031-2050
# Details siehe http://www.worldclim.com/cmip5_5m
download.file(url="http://biogeo.ucdavis.edu/data/climate/cmip5/5m/hd45bi50.zip",
              destfile=paste0(path.envir.future, "hd45bi50.zip"),
              method="internal", mode="wb")
unzip(zipfile=paste0(path.envir.future, "hd45bi50.zip"), exdir=path.envir.future)

# Shapefile mit den Umrissen von Japan
# ACHTUNG: Die folgenden Daten duerfen nur fuer nicht-kommerzielle Zwecke verwendet werden.
# Details siehe Datei "read_me.pdf" (im Download enthalten) und http://www.gadm.org/country
download.file(url="http://biogeo.ucdavis.edu/data/gadm2/shp/JPN_adm.zip",
              destfile=paste0(path.misc, "JPN_adm.zip"),
              method="internal", mode="wb")
unzip(zipfile=paste0(path.misc, "JPN_adm.zip"), exdir=path.misc)

# Projizierte Temperaturdaten in taeglicher Aufloesung muessen manuell heruntergeladen werden.
# Diese sind fuer reine Verbreitungsmodellierung eines Vektors NICHT erforderlich.
# Wir werden in diesem Beispiel der Einfachheit halber nur mit Mitteltemperaturen 
# (nicht Minimum oder Maximum) arbeiten.
# Wir verwenden hier Daten des Klimamodells MPI-ESM-LR fuer das Klimaszenario
# rcp45 und den Zeitabschnitt 2031-2050
# Diese Daten koennen vom Deutschen Klimarechenzentrum (DKRZ) heruntergeladen werden
# (Es ist jeweils die Anlage eines Benutzeraccounts noetig):
# * aktuelle Daten ueber den DKRZ-Datenknoten der Earth System Grid Foundation (ESGF)
#   http://esgf-data.dkrz.de/
# * alternativ archivierte Daten ueber das World Data Center for Climate Data
#   http://cera-www.dkrz.de/
#   direkteinstieg ueber
#   http://cera-www.dkrz.de/WDCC/ui/containerArchive?acronym=MXELr4DADtas111v111006
#
# Herguntergeladen werden müssen die Folgenden Dateien:
# tas_day_MPI-ESM-LR_rcp45_r1i1p1_20300101-20391231.nc
# tas_day_MPI-ESM-LR_rcp45_r1i1p1_20400101-20491231.nc
# tas_day_MPI-ESM-LR_rcp45_r1i1p1_20500101-20591231.nc
# Es wird erwartet, dass diese im Unterverzeichnis 
# ".../RISKTOOL_example/data/environment/daily_temperature/"
# abgelegt werden, andernfalls muss der Pfad für path.tas in risktool-settings.r
# angepasst werden.
#
# Diese Daten haben eine verhaeltnismaessig geringe Raeumliche Aufloesung.
# Daten mit hoeherer Aufloesung stellen z.B. die regionalen CORDEX-Projekte
# zur Verfuegung (http://www.cordex.org/)
# Die Verarbeitung der Daten erfolgt analog zu den hier verwendeten, 
# benoetigt aber unter Umstaenden erheblich mehr Festplattenspeicher
# und Rechenzeit.

#############################################################
# Zuschneiden der Klimadaten auf das Untersuchungsgebiet
# (hier: Japan)

# Shapefile laden
cropshape <- readOGR(dsn=substr(path.misc, start=1, stop=nchar(path.misc)-1), layer="JPN_adm0" )
plot(cropshape)

# baseline-Klimadaten zuschneiden
# die zugeschnittenen Umweltdaten befinden sich anschliessend im Unterverzeichnis
# ./data/environment/bioclim_baseline/cropped/
for(varname in 1:19){
  dat <- raster(paste0(path.envir.baseline, "bio/bio_", varname), RAT=FALSE)
  dat.crop <- rt.clip(data=dat, cropshape=cropshape)
  writeRaster(x=dat.crop, filename=paste0(path.envir.baseline.cropped, "bio_", varname, ".tif"))
}

# Zukunfts-Klimadaten zuschneiden
# die zugeschnittenen Umweltdaten befinden sich anschliessend im Unterverzeichnis
# ./data/environment/bioclim_future/cropped/
for(varname in 1:19){
  dat <- raster(paste0(path.envir.future, "/hd45bi50", varname, ".tif"), RAT=FALSE)
  dat.crop <- rt.clip(data=dat, cropshape=cropshape)
  writeRaster(x=dat.crop, filename=paste0(path.envir.future.cropped, "bio_", varname, ".tif"))
}






