###########################################
##                                       ##
##    Teilskript 2: Variablenselektion   ##
##                                       ##
###########################################


#############################################################
# falls Session unterbrochen wurde: risktool-settings.r erneut laden.
#source("./code/risktool-settings.r")

#############################################################
# 1. Vorkommensdaten einlesen

# Einlesen der Vorkommen (hier mit read.csv) und Konvertierung in ein "Spatial*" Objekt
pres <- read.csv(file=paste0(path.speciesdata, "Ae_japonicus_Japan.csv"), header=TRUE, sep=";", dec=".")
summary(pres) # Zusammenfassung der Daten
#pres <- subset(pres, pres$exclude != "yes") # Entfernen von Zeilen mit ungenuegenden Koordinaten (oder sonstige Ausschlusskriterien)
pres <- pres[,c("longitude", "latitude")]   # Extrahieren der Spalten "longitude" und "latitude" (d.h. die Koordinaten)
pres <- na.omit(pres) # Entfernt Zellen, die NAs (d.h. keine Information) enthalten
pres.sp <- SpatialPoints(pres, proj4string=proj4.pres) # Konvertierung in SpatialPoints Objekt mit der vorgegebenen Projektion (proj4)
plot(pres.sp)

# Konvertierung der Vorkommenspunkte ins Grid-Format
# Fuer jede Zelle der Raster-Dateien, die fuer das Erstellen des Modells verwendet werden
# benoetigen wir die Information, ob die Art vorkommt.

# einen Umwelt-Layer als Referenz einladen
env.tmp <- raster(paste0(path.envir.baseline.cropped, envlayers[1], ".tif"))

# Verwendung des "raster" Paketes zum Erstellen eines Rasters aus den Vorkommenspunkten, die mit den Umweltdaten uebereinstimmen
pres.grd <- rasterize(pres.sp, env.tmp) # rasterize: Umwandlung von raeumlichen Daten (hier spatial points) in Rasterzellen
# Konvertierung in ein SpatialGridDataFrame (aehnlich einem "raster"-Objekt, ermoeglicht aber einfacheren Zugriff auf die enthaltenen Daten)
pres.grd <- as(pres.grd, ("SpatialGridDataFrame"))
# In diesem Raster wurden alle Pixel, in denen die Art nicht vorkommt, auf "NA" (Not Available, nicht verfuebar) gesetzt.
# Die Pixel, in denen die Art vorkommt, haben den gleichen Wert wie das zuvor geladene Umweltgrid an dieser Stelle hatte.
# Da wir nur die Information benoetigen, dass die Art vorkommt, aendern wir diesen Wert in "1" und die NAs in "0".
pres.grd@data$layer[which(!is.na(pres.grd@data$layer))] <- 1
pres.grd@data$layer[which(is.na(pres.grd@data$layer))] <- 0

# OPTIONAL: Speichern der erzeugten Datei fuer ueberpruefungszwecke in GIS Software
#writeGDAL(pres.grd, fname=paste0(path.misc, "presence-test.tif"))

# Fuer die Variablenselektion benoetigen wir nur einen Vektor mit 1/0 in der korrekten Reihenfolge.
# Diesen erhaelt man durch einfache Extraktion des Datenstrangs aus dem Raster.
pres.vector <- pres.grd@data$layer

#############################################################
# 2. Umweltdaten einlesen:
# Erstellen einer Tabelle, die die Werte aller Umweltvariablen enthaelt

# Einlesen der Datenreihe der ersten Variable
env.selection <- values(raster(paste0(path.envir.baseline.cropped, envlayers[1], ".tif")))
# Konvertierung des Vektors in einen dataframe (fundamentale Datenstruktur in R)
env.selection <- data.frame(env.selection)

# Anfuegen der Daten der uebrigen Umweltvariablen mittels einer for-Schleife (for(){})
for(layer in envlayers[2:length(envlayers)]){
  # Einlesen der Daten vom jeweils naechsten Layer im Datensatz
  dat.temp <- values(raster(paste0(path.envir.baseline.cropped, layer, ".tif", sep="")))
  # ... und Anfuegen dieser an den bestehenden dataframe
  env.selection <- cbind(env.selection, dat.temp)
}
# Ergaenzen von geeigneten Namen faer die einzelnen Spalten mit names()
names(env.selection) <- envlayers

# Gebiete (Rasterzellen/Pixel), in denen keine Klimadaten vorliegen (z.B. Ozeane) enthalten "NA" statt Daten
# Diese werden hier verworfen - sowohlm im Vektor mit den Vorkommen als auch in der Matrix mit den Umweltvariablen
pres.vector <- subset(pres.vector, !is.na(env.selection)[,1])
env.selection <- subset(env.selection, !is.na(env.selection)[,1])

#############################################################
# 3. Variablenauswahl mit hierarchischer Partitionierung
# Es koennen maximal 12 Variablen beruecksichtigt werden!
# Eine auf Expertenwissen beruhende Vor-Auswahl ist daher noetig

varimportance <- hier.part(pres.vector,  # Vorkommensdaten bzw. abhaengige Variable
                           env.selection[,c(1, 5:6, 8:11, 14, 16:18)], # Umweltvariablen (Vorauswahl aus den 19 bioclim Variablen) bzw. unabhaengige Variablen
                           fam = "binomial", gof = "logLik" )  # fam: Fehlerverteilung fuers GLM, gof: "goodness-of-fit measure"

varimportance$I.perc # prozentualer Anteil der einzelnen Variablen an der erklaerten Varianz
                     # wichtigste Variablen im Beispiel: bio_1, bio_6, bio_10, bio_11


