################################################################################################
##                                                                                           ##
##    Teilskript 4: Ueberlebensfaehigkeit des Vektors basierend auf Temperatur-Grenzwerten   ##
##                                                                                           ##
###############################################################################################

#############################################################
# falls Session unterbrochen wurde: risktool-settings.r erneut laden.
#source("./code/risktool-settings.r")


###################################################################
#                     Datenaufbereitung                           #
###################################################################

##################
# Bitte beachten, dass hierzu Klimadaten in taeglicher Aufloesung manuell
# heruntergeladen werden muessen. Siehe dazu Teilskript 1!

# Variablennamen fuer Mitteltemperatur in ntcdf-Dateien angeben (insbesondere dann
# noetig, wenn eine Datei mehrere Klimaparameter enthaelt)
varname<-"tas"

# Shapefile fuer den Zuschnitt der Daten auf Japan (erneut) laden
cropshape <- readOGR(dsn=substr(path.misc, start=1, stop=nchar(path.misc)-1), layer="JPN_adm0" )

# Vollstaendige Pfade zu Klimadaten-Dateien einlesen
filenames.tas <- dir(path.tas, pattern=".nc", full.names=TRUE)
#Ueberpruefen:
filenames.tas

# Mitteltemperaturen fuer jeden Tag im Jahr (1. Januar, 2. Januar, ... 31. Dezember)
# ueber den Untersuchungszeitraum (2031-2050) mitteln
rt.extract365(infiles = filenames.tas,   # Pfade zu Eingabedateien
              startyear = 2031,          # erstes zu beruecksichtigendes Jahr
              endyear = 2050,            # letztes zu beruecksichtigendes Jahr
              path.outfiles = paste0(path.tas, "2031-2050_means_cropped/"), # Ausgabepfad
              cropshape = cropshape,     # SpatialPolygons* Objekt fuer Zuschnitt auf Japan
              cropmode = "crop",         # nur Grober Zuschnitt (fuer feineren Zuschnitt entlang der Umrisse "clip" waehlen)
              fname.prefix="tas_day",    # 
              fun=mean,
              varname=varname,
              overwrite=FALSE
              )

###################################################################
#                     Ueberlebensfaehigkeit                       #
###################################################################
# Nehmen wir zu Demonstrationszwecken an, Experimente haetten gezeigt
# dass unser Vektor bei Temperaturen von mehr als 30°C sofort stirbt.
# (Die tatsaechlich experimentell gefundene Temperatur-Untergrenze fuer
# das Ueberleben von Ae. japoicus-Eiern laesst sich mit den hier
# verwendeten, raumlich grob aufgeloesten Daten leider nicht darstellen)

# Festlegen einer Grenztemperatur:
# Temperaturdaten werden von Klimatologen oft in "Grad Celsius x 10"
# gespeichert. Dies ist auch bei unseren Beispieldaten der Fall, weshalb
# wir auch unseren Grenzwert mit 10 multiplizieren
threshold <- 30 * 10

# Definition der Eingabedaten
filenames.temperatures <- dir(paste0(path.tas, "2031-2050_means_cropped/"), pattern=".tif$", full.names=TRUE)

# Anzahl an Tagen mit mehr als 30°C
hotdays.number <-  rt.threshold(filenames=filenames.temperatures, threshold=threshold, thresholdside="above")
plot(hotdays.number)
plot(cropshape, add=TRUE)

######################
# Ueberlagerung mit dem Artverbreitungsmodel fuer diesen Zeitabschnitt

# Rasterzellen mit Ueberleben auf 0, ohne Ueberleben auf 1 setzen
survives <- hotdays.number
survives[which(hotdays.number[]>0)] <- 0
survives[which(hotdays.number[]==0)] <- 1

# Artverbreitungsmodell (SDM) laden (Ensemble-Mittel)
sdm <- raster(paste0(path.output, "testspecies_ensemble_future_testspecies_EMmeanByROC_mergedAlgo_mergedRun_mergedData.tif"))
plot(sdm)

# Raeumliche Aufloesung von "survives" an die feinere Aufloesung des sdm anpassen
survives.res <- resample(survives, sdm, method="ngb")

# Errechnete Klimatische Eignung des Verbreitungsmodells in Gebieten mit laut Experiment
# nicht vorhandener Ueberlebensfaehigkeit durch einfache Multiplikation auf 0 setzen;
# in allen anderen Gebieten bleiben die Werte des SDM erhalten
sdm.survival <- sdm*survives.res
plot(sdm.survival)

# alternativ mit bilinearer interpolation fuer weniger scharfe Grenzen:
#survives.res <- resample(survives, sdm, method="bilinear")
#sdm.survival <- sdm*survives.res
#plot(sdm.survival)

# Als TIF zur weiteren Verwendung in externen Programmen abspeichern
writeRaster(sdm.survival, paste0(path.output, "sdm_survival.tif"))





