################################################################################################
##                                                                                           ##
##        Teilskript 5: Temperaturabhaengigkeit der Extrinsischen Inkubationsperiode         ##
##                                                                                           ##
###############################################################################################

#############################################################
# falls Session unterbrochen wurde: risktool-settings.r erneut laden.
#source("./code/risktool-settings.r")

######################################################################
# Nehmen wir zu Demonstrationszwecken an, ein Experiment haette einen
# einfachen linearen Zusammenhang zwischen der Umgebungstemperatur
# (in Grad Celsius) und der Extrinsischen Inkubationsperiode (EIP, 
# in Tagen) eines von unserem Beispielvektor uebertragenen
# Virus festgestellt:
# EIP=45-Temperatur

# Beispieldaten erzeugen
eip.experiment <- data.frame(Temperatur=15:40, EIP=45-(15:40))
eip.experiment
plot(eip.experiment)

# Dateinamen der ueber den Untersuchungszeitraum gemittelten Tagestemperaturen einlesen
# (Daten erstellt in Teilskript 4)
filenames.temperatures <- dir(paste0(path.tas, "2031-2050_means_cropped/"), pattern=".tif$", full.names=TRUE)
# Daten einlesen
dat <- rt.consdaysdata(filenames.temperatures)

######################################################################
# Beispielhaft: Maximale Anzahl aufeinanderfolgender Tage bei >= 28 Grad (angegeben als 280)
days28 <- rt.consdays(data=dat, referencevalue=280, startday=1, endday=365)
days28 # angabe für jede Rasterzelle
# Umwandlung in geographische Daten
days28.geo <- dat                          # Kopieren der Geoinformation der Eingangsdaten
days28.geo@data <- data.frame(days=days28) # Ueberschreiben der Eingangsdaten mit den Ausgabedaten
days28.geo <- raster(days28.geo)           # SpatialGridDataFrame wegen besserer Plot-Funktion in Raster umwandeln
plot(days28.geo)                           # Plotten


######################################################################
# Kuerzest moegliche EIP, indirekter Aufruf von rt.consdays durch rt.eip_duration

eip <- rt.eip_duration(data=dat,                                  # Temperaturdaten (Klimamodelle)
                       eips=eip.experiment$EIP,                   # Experimentell ermittelte dauer der EIP ...
                       temperatures=eip.experiment$Temperatur*10, # ... dem entsprechende Temperaturen (*10 wegen Datenformat der Klimadaten)
                       startday=1, endday=365)                    # Falls nur ein Teilzeitraum eines Jahres betrachtet werden soll

plot(eip)

######################################################################
# Erzeugen eines Risikoindex aus SDM und EIP

# SDM zum Verschnitt einlesen
sdm <- raster(paste0(path.output, "testspecies_ensemble_future_testspecies_EMmeanByROC_mergedAlgo_mergedRun_mergedData.tif"))
# Wertebereich fuer suitability ist intern 0-1000
# -> auf Werte zwischen 0 und 1 normieren
sdm.norm <- sdm/1000

# EIP zum Verschnitt vorbereiten:
# * Kehrwert bilden und auf Werte zwischen 0 und 1 normieren
# * gleichzeitig an Aufloesung des SDM anpassen
eip.norm <- rt.transformEIP(eip, refraster=sdm)

# SDM und EIP multiplizieren um Risikoindex zu erhalten
risk <- sdm.norm*eip.norm

# Vergleichsplot
par(mfrow=c(2,1))
plot(sdm.norm, main = "SDM")
plot(risk, main = "SDM * EIP")
par(mfrow=c(1,1))

# Als TIF zur weiteren Verwendung in externen Programmen abspeichern
writeRaster(risk, paste0(path.output, "risk-index.tif"))









